/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct RootObj RootObj;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__TAsXwXSUBvAawE1kIQ5ziQ[1];
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* info_p0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_u39)(NimStringV2 x_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__extccomp_u1334)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* c_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pathutils_u73)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1619)(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__extccomp_u977)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOption__extccomp_u906)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOption__extccomp_u909)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1);
N_LIB_PRIVATE N_NIMCALL(void, addLocalCompileOption__extccomp_u961)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1, NimStringV2 nimfile_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPathConsiderDirty__msgs_u657)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_u2159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* c_p0, NimStringV2 define_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, getOrDefault__vm_u4335)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u4773)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0, NimStringV2 key_p1, NI64 val_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u8108)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u8529)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, NimStringV2 key_p1, tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw val_p2);
N_LIB_PRIVATE N_NIMCALL(void, initBTree__vm_u8410)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u9814)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw b_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*, X5BX5D___vm_u9673)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__vm_u10092)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* b_p0, NimStringV2 key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u5937)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u6248)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, NimStringV2 key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTree__ast_u4170)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p1, NI children_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___vm_u7388)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_u63)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1, NIM_BOOL strictSymEquality_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, translateId__icZic_u21415)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig id_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI thisModule_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p3);
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u7226)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* x_p0, tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__vb3AGHvMJTxdOSSwMmBmTQ*, mgetOrPut__semdata_u6085)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__vb3AGHvMJTxdOSSwMmBmTQ val_p2);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig, eqdup___icZpacked95ast_u675)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig src_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__YxH9cgSorHRI8ZPzHf47NNQ, newSeq__icZreplayer_u1639)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u6001)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* x_p0, tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__apM9bRAO19cVjhWlxqd1PGeA*, mgetOrPut__semdata_u4860)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__apM9bRAO19cVjhWlxqd1PGeA val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1203)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1206)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u10641)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* x_p0, tyTuple__lGHLhAAUpxgfrnQkIzNrMw* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*, mgetOrPut__modulegraphs_u9537)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw val_p2);
N_LIB_PRIVATE N_NIMCALL(void, replayBackendProcs__icZreplayer_u893)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_u5663)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA val_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u6885)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* x_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA*, mgetOrPut__icZreplayer_u1090)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__olFOFaYzOJN9aV5BWqK4b9bA val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, loadSymFromId__icZic_u21336)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, NI module_p3, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig id_p4);
N_LIB_PRIVATE N_NIMCALL(void, methodDef__cgmeth_u202)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_3 = {0, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_4 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_5 = {1, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_4};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_6 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_7 = {2, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_6};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_8 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_9 = {1, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_8};
static const struct {
  NI cap; NIM_CHAR data[66+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_11 = { 66 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ic/replayer.nim" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_12 = { 4 | NIM_STRLIT_FLAG, "hint" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_13 = {4, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_12};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_14 = { 7 | NIM_STRLIT_FLAG, "warning" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_15 = {7, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_14};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_16 = { 5 | NIM_STRLIT_FLAG, "error" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_17 = {5, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_16};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_18 = { 7 | NIM_STRLIT_FLAG, "compile" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_19 = {7, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_18};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_20 = { 4 | NIM_STRLIT_FLAG, "link" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_21 = {4, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_20};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_22 = { 5 | NIM_STRLIT_FLAG, "passl" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_23 = {5, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_22};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_24 = { 5 | NIM_STRLIT_FLAG, "passc" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_25 = {5, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_24};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_26 = { 10 | NIM_STRLIT_FLAG, "localpassc" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_27 = {10, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_26};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_28 = { 9 | NIM_STRLIT_FLAG, "cppdefine" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_29 = {9, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_28};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_30 = { 3 | NIM_STRLIT_FLAG, "inc" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_31 = {3, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_30};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_32 = { 3 | NIM_STRLIT_FLAG, "put" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_33 = {3, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_32};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_34 = { 4 | NIM_STRLIT_FLAG, "incl" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_35 = {4, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_34};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_36 = { 3 | NIM_STRLIT_FLAG, "add" };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_37 = {3, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_36};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MWLujk8qP0XkmYs4m9cuPow_42 = { 20 | NIM_STRLIT_FLAG, "key already exists: " };
static const NimStringV2 TM__MWLujk8qP0XkmYs4m9cuPow_43 = {20, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_42};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_10 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)33),
((NI)6)}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_38 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)35),
((NI)24)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_39 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)36),
((NI)27)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_40 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)37),
((NI)28)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_41 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)39),
((NI)8)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_44 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)70),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MWLujk8qP0XkmYs4m9cuPow_45 = {{66, (NimStrPayload*)&TM__MWLujk8qP0XkmYs4m9cuPow_11},
((NI)90),
((NI)8)}
;
extern NIM_BOOL nimInErrorMode__system_u4146;
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* info_p0) {
	NimStringV2 result;
	result = TM__MWLujk8qP0XkmYs4m9cuPow_3;
	prepareAdd((&result), (*info_p0).Field0.len + 0);
appendString((&result), (*info_p0).Field0);
	{
		if (!(((NI)0) < (*info_p0).Field1)) goto LA3_;
		prepareAdd((&result), 1);
appendString((&result), TM__MWLujk8qP0XkmYs4m9cuPow_5);
		addInt__stdZprivateZdigitsutils_u204((&result), (*info_p0).Field1);
		{
			if (!(((NI)0) < (NI)((*info_p0).Field2 + ((NI)1)))) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__MWLujk8qP0XkmYs4m9cuPow_7);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)((*info_p0).Field2 + ((NI)1)));
		}
LA7_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__MWLujk8qP0XkmYs4m9cuPow_9);
	}
LA3_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, replayStateChanges__icZreplayer_u16)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* list_1;
NIM_BOOL oldNimErrFin63_;
NIM_BOOL oldNimErrFin96_;
NIM_BOOL oldNimErrFin85_;
NIM_BOOL oldNimErrFin111_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	list_1 = NIM_NIL;
	eqcopy___ast_u3255(&list_1, (*module_p0).ast);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		n_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(list_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA6;
					i_1 = i_2;
					eqcopy___ast_u3255(&n_1, (*list_1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					{
						NI T9_;
						T9_ = (NI)0;
						T9_ = len__ast_u3190(n_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						if (!(((NI)2) <= T9_)) goto LA10_;
						{
							NIM_BOOL T14_;
							NimStringV2 argX60gensym10__1;
							T14_ = (NIM_BOOL)0;
							T14_ = ((*(*n_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
							if (!(T14_)) goto LA15_;
							T14_ = ((*(*n_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
LA15_: ;
							if (!!(T14_)) goto LA16_;
							argX60gensym10__1.len = 0; argX60gensym10__1.p = NIM_NIL;
							argX60gensym10__1 = toFileLineCol__msgs_u701((&TM__MWLujk8qP0XkmYs4m9cuPow_10));
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							internalErrorImpl__msgs_u1598((*g_p1).config, unknownLineInfo__lineinfos_u364, argX60gensym10__1, (&TM__MWLujk8qP0XkmYs4m9cuPow_10));
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							{
								LA18_:;
							}
							{
								eqdestroy___system_u2691(argX60gensym10__1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
LA16_: ;
						switch (hashString((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal) & 15) {
						case 0: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_15)) goto LA22_;
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_21)) goto LA25_;
break;
						case 2: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_19)) goto LA24_;
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_37)) goto LA33_;
break;
						case 3: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_31)) goto LA30_;
break;
						case 4: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_17)) goto LA23_;
break;
						case 5: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_23)) goto LA26_;
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_33)) goto LA31_;
break;
						case 6: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_27)) goto LA28_;
break;
						case 11: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_13)) goto LA21_;
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_29)) goto LA29_;
break;
						case 12: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_25)) goto LA27_;
break;
						case 15: 
if (eqStrings((*(*n_1)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal, TM__MWLujk8qP0XkmYs4m9cuPow_35)) goto LA32_;
break;
						}
						goto LA34_;
						LA21_: ;
						{
							liMessage__msgs_u1227((*g_p1).config, (*n_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)118), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__MWLujk8qP0XkmYs4m9cuPow_38), NIM_FALSE, NIM_FALSE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA22_: ;
						{
							liMessage__msgs_u1227((*g_p1).config, (*n_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__MWLujk8qP0XkmYs4m9cuPow_39), NIM_FALSE, NIM_FALSE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA23_: ;
						{
							liMessage__msgs_u1227((*g_p1).config, (*n_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__MWLujk8qP0XkmYs4m9cuPow_40), NIM_FALSE, NIM_FALSE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA24_: ;
						{
							NimStringV2 cname_1;
							NimStringV2 colontmpD_;
							tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg cf_1;
							NimStringV2 colontmpD__2;
							tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__3;
							NimStringV2 colontmpD__4;
							NimStringV2 colontmpD__5;
							NimStringV2 blitTmp_1;
							cname_1.len = 0; cname_1.p = NIM_NIL;
							nimZeroMem((void*)(&cf_1), sizeof(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
							nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
							{
								NIM_BOOL T43_;
								NI T44_;
								NimStringV2 argX60gensym23__1;
								T43_ = (NIM_BOOL)0;
								T44_ = (NI)0;
								T44_ = len__ast_u3190(n_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
								T43_ = (T44_ == ((NI)4));
								if (!(T43_)) goto LA45_;
								T43_ = ((*(*n_1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
LA45_: ;
								if (!!(T43_)) goto LA46_;
								argX60gensym23__1.len = 0; argX60gensym23__1.p = NIM_NIL;
								argX60gensym23__1 = toFileLineCol__msgs_u701((&TM__MWLujk8qP0XkmYs4m9cuPow_41));
								if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
								internalErrorImpl__msgs_u1598((*g_p1).config, unknownLineInfo__lineinfos_u364, argX60gensym23__1, (&TM__MWLujk8qP0XkmYs4m9cuPow_41));
								if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
								{
									LA48_:;
								}
								{
									eqdestroy___system_u2691(argX60gensym23__1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							}
LA46_: ;
							colontmpD_ = eqdup___system_u2697((*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							cname_1 = colontmpD_;
							splitFile__pathutils_u39(cname_1, (&colontmpD__3));
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							colontmpD__2 = eqdup___system_u2697(colontmpD__3.Field1);
							cf_1.nimname = colontmpD__2;
							blitTmp_1 = cname_1;
							eqwasMoved___system_u2688((&cname_1));
							cf_1.cname = blitTmp_1;
							colontmpD__4 = eqdup___system_u2697((*(*n_1)._kind_6.sons.p->data[((NI)2)])._kind_3.strVal);
							cf_1.obj = colontmpD__4;
							cf_1.flags = 2;
							colontmpD__5 = eqdup___system_u2697((*(*n_1)._kind_6.sons.p->data[((NI)3)])._kind_3.strVal);
							cf_1.customArgs = colontmpD__5;
							addExternalFileToCompile__extccomp_u1334((*g_p1).config, (&cf_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							{
								LA40_:;
							}
							{
								eqdestroy___pathutils_u73((&colontmpD__3));
								eqdestroy___options_u1619((&cf_1));
								eqdestroy___system_u2691(cname_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA25_: ;
						{
							addExternalFileToLink__extccomp_u977((*g_p1).config, (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA26_: ;
						{
							addLinkOption__extccomp_u906((*g_p1).config, (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA27_: ;
						{
							addCompileOption__extccomp_u909((*g_p1).config, (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA28_: ;
						{
							NimStringV2 colontmpD__6;
							colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
							colontmpD__6 = toFullPathConsiderDirty__msgs_u657((*g_p1).config, (*module_p0).info.fileIndex);
							if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
							addLocalCompileOption__extccomp_u961((*g_p1).config, (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal, colontmpD__6);
							if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
							{
								LA57_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__6);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA29_: ;
						{
							cppDefine__options_u2159((*g_p1).config, (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA30_: ;
						{
							NimStringV2 destKey_1;
							NI64 by_1;
							NI64 v_1;
							destKey_1.len = 0; destKey_1.p = NIM_NIL;
							eqcopy___system_u2694((&destKey_1), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							by_1 = (*(*n_1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal;
							v_1 = getOrDefault__vm_u4335((*g_p1).cacheCounters, destKey_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							X5BX5Deq___vm_u4773((&(*g_p1).cacheCounters), destKey_1, (NI64)(v_1 + by_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							eqdestroy___system_u2691(destKey_1);
						}
						goto LA35_;
						LA31_: ;
						{
							NimStringV2 destKey_2;
							NimStringV2 key_1;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_1;
							destKey_2.len = 0; destKey_2.p = NIM_NIL;
							key_1.len = 0; key_1.p = NIM_NIL;
							val_1 = NIM_NIL;
							eqcopy___system_u2694((&destKey_2), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							eqcopy___system_u2694((&key_1), (*(*n_1)._kind_6.sons.p->data[((NI)2)])._kind_3.strVal);
							eqcopy___ast_u3255(&val_1, (*n_1)._kind_6.sons.p->data[((NI)3)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
							{
								NIM_BOOL T66_;
								tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw T69_;
								T66_ = (NIM_BOOL)0;
								T66_ = contains__vm_u8108((*g_p1).cacheTables, destKey_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
								if (!!(T66_)) goto LA67_;
								nimZeroMem((void*)(&T69_), sizeof(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw));
								initBTree__vm_u8410((&T69_));
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
								X5BX5Deq___vm_u8529((&(*g_p1).cacheTables), destKey_2, T69_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
							}
LA67_: ;
							{
								tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T72_;
								NIM_BOOL T73_;
								tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* T76_;
								T72_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
								T72_ = X5BX5D___vm_u9673((&(*g_p1).cacheTables), destKey_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
								T73_ = (NIM_BOOL)0;
								T73_ = contains__vm_u9814((*T72_), key_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
								if (!!(T73_)) goto LA74_;
								T76_ = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
								T76_ = X5BX5D___vm_u9673((&(*g_p1).cacheTables), destKey_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
								add__vm_u10092(T76_, key_1, val_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
							}
							goto LA70_;
LA74_: ;
							{
								NimStringV2 colontmpD__7;
								NimStringV2 T79_;
								colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
								T79_.len = 0; T79_.p = NIM_NIL;
								T79_ = rawNewString(key_1.len + 20);
appendString((&T79_), TM__MWLujk8qP0XkmYs4m9cuPow_43);
appendString((&T79_), key_1);
								colontmpD__7 = T79_;
								internalErrorImpl__msgs_u1598((*g_p1).config, (*n_1).info, colontmpD__7, (&TM__MWLujk8qP0XkmYs4m9cuPow_44));
								if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
								{
									LA78_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__7);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
							}
LA70_: ;
							{
								LA63_:;
							}
							{
								oldNimErrFin63_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(val_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
								eqdestroy___system_u2691(key_1);
								eqdestroy___system_u2691(destKey_2);
								*nimErr_ = oldNimErrFin63_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA32_: ;
						{
							NimStringV2 destKey_3;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_2;
							destKey_3.len = 0; destKey_3.p = NIM_NIL;
							val_2 = NIM_NIL;
							eqcopy___system_u2694((&destKey_3), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							eqcopy___ast_u3255(&val_2, (*n_1)._kind_6.sons.p->data[((NI)2)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
							{
								NIM_BOOL T88_;
								tyArray__TAsXwXSUBvAawE1kIQ5ziQ T91_;
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T92_;
								T88_ = (NIM_BOOL)0;
								T88_ = contains__vm_u5937((*g_p1).cacheSeqs, destKey_3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
								if (!!(T88_)) goto LA89_;
								nimZeroMem((void*)T91_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
								T91_[0] = val_2;
								T92_ = NIM_NIL;
								T92_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), T91_, 1);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T92_); goto LA85_;}
								X5BX5Deq___vm_u6248((&(*g_p1).cacheSeqs), destKey_3, T92_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
							}
							goto LA86_;
LA89_: ;
							{
								{
									tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T107_;
									{
										tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* existing_1;
										tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp__2;
										existing_1 = NIM_NIL;
										existing_1 = 0;
										colontmp__2 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
										colontmp__2 = X5BX5D___vm_u7388((&(*g_p1).cacheSeqs), destKey_3);
										if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
										{
											NI i_3;
											NI colontmp__3;
											NI i_4;
											i_3 = (NI)0;
											colontmp__3 = (NI)0;
											colontmp__3 = safeLen__ast_u3197((*colontmp__2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
											i_4 = ((NI)0);
											{
												while (1) {
													if (!(i_4 < colontmp__3)) goto LA99;
													i_3 = i_4;
													eqcopy___ast_u3255(&existing_1, (*(*colontmp__2))._kind_6.sons.p->data[i_3]);
													if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
													{
														NIM_BOOL T102_;
														T102_ = (NIM_BOOL)0;
														T102_ = exprStructuralEquivalent__trees_u63(existing_1, val_2, NIM_TRUE);
														if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
														if (!T102_) goto LA103_;
														eqdestroy___ast_u3252(existing_1);
														if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
														goto LA94;
													}
LA103_: ;
													i_4 += ((NI)1);
												} LA99: ;
											}
										}
										{
											LA96_:;
										}
										{
											oldNimErrFin96_ = *nimErr_; *nimErr_ = NIM_FALSE;
											eqdestroy___ast_u3252(existing_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
											*nimErr_ = oldNimErrFin96_;
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
									}
									T107_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
									T107_ = X5BX5D___vm_u7388((&(*g_p1).cacheSeqs), destKey_3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
									add__ast_u3215((*T107_), val_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
								} LA94: ;
							}
LA86_: ;
							{
								LA85_:;
							}
							{
								oldNimErrFin85_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(val_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
								eqdestroy___system_u2691(destKey_3);
								*nimErr_ = oldNimErrFin85_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA33_: ;
						{
							NimStringV2 destKey_4;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_3;
							destKey_4.len = 0; destKey_4.p = NIM_NIL;
							val_3 = NIM_NIL;
							eqcopy___system_u2694((&destKey_4), (*(*n_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
							eqcopy___ast_u3255(&val_3, (*n_1)._kind_6.sons.p->data[((NI)2)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
							{
								NIM_BOOL T114_;
								tyArray__TAsXwXSUBvAawE1kIQ5ziQ T117_;
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T118_;
								T114_ = (NIM_BOOL)0;
								T114_ = contains__vm_u5937((*g_p1).cacheSeqs, destKey_4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
								if (!!(T114_)) goto LA115_;
								nimZeroMem((void*)T117_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
								T117_[0] = val_3;
								T118_ = NIM_NIL;
								T118_ = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), T117_, 1);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T118_); goto LA111_;}
								X5BX5Deq___vm_u6248((&(*g_p1).cacheSeqs), destKey_4, T118_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
							}
							goto LA112_;
LA115_: ;
							{
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T120_;
								T120_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
								T120_ = X5BX5D___vm_u7388((&(*g_p1).cacheSeqs), destKey_4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
								add__ast_u3215((*T120_), val_3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
							}
LA112_: ;
							{
								LA111_:;
							}
							{
								oldNimErrFin111_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(val_3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
								eqdestroy___system_u2691(destKey_4);
								*nimErr_ = oldNimErrFin111_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						}
						goto LA35_;
						LA34_: ;
						{
							{
								NimStringV2 argX60gensym44__1;
								if (!NIM_TRUE) goto LA126_;
								argX60gensym44__1.len = 0; argX60gensym44__1.p = NIM_NIL;
								argX60gensym44__1 = toFileLineCol__msgs_u701((&TM__MWLujk8qP0XkmYs4m9cuPow_45));
								if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
								internalErrorImpl__msgs_u1598((*g_p1).config, unknownLineInfo__lineinfos_u364, argX60gensym44__1, (&TM__MWLujk8qP0XkmYs4m9cuPow_45));
								if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
								{
									LA128_:;
								}
								{
									eqdestroy___system_u2691(argX60gensym44__1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							}
LA126_: ;
						}
LA35_: ;
					}
LA10_: ;
					i_2 += ((NI)1);
				} LA6: ;
			}
		}
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(list_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, replayBackendProcs__icZreplayer_u893)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyTuple__6kG8KAxm9aXPdLdlxcxqJJw* it_1;
		NI i_1;
		NI L_1;
		NI T2_;
		it_1 = (tyTuple__6kG8KAxm9aXPdLdlxcxqJJw*)0;
		i_1 = ((NI)0);
		T2_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.attachedOps.len;
		L_1 = T2_;
		{
			while (1) {
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_1;
				tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_1;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tmp_1;
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_1;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T5_;
				if (!(i_1 < L_1)) goto LA4;
				it_1 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.attachedOps.p->data[i_1]);
				key_1 = translateId__icZic_u21415((*it_1).Field0, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				op_1 = (*it_1).Field1;
				tmp_1 = translateId__icZic_u21415((*it_1).Field2, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				symId_1.module = ((NI) (tmp_1.module));
				symId_1.packed_0 = (*it_1).Field2;
				nimZeroMem((void*)(&T5_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T5_.id = symId_1;
				T5_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				X5BX5Deq___modulegraphs_u5663((&(*g_p0).attachedOps[(op_1)- 0]), key_1, T5_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	{
		tyTuple__qPXRCRNQuZLLKto7CIIEzw* it_2;
		NI i_2;
		NI L_2;
		NI T7_;
		it_2 = (tyTuple__qPXRCRNQuZLLKto7CIIEzw*)0;
		i_2 = ((NI)0);
		T7_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.enumToStringProcs.len;
		L_2 = T7_;
		{
			while (1) {
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_2;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tmp_2;
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_2;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T10_;
				if (!(i_2 < L_2)) goto LA9;
				it_2 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.enumToStringProcs.p->data[i_2]);
				key_2 = translateId__icZic_u21415((*it_2).Field0, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				tmp_2 = translateId__icZic_u21415((*it_2).Field1, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				symId_2.module = ((NI) (tmp_2.module));
				symId_2.packed_0 = (*it_2).Field1;
				nimZeroMem((void*)(&T10_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T10_.id = symId_2;
				T10_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				X5BX5Deq___modulegraphs_u5663((&(*g_p0).enumToStringProcs), key_2, T10_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA9: ;
		}
	}
	{
		tyTuple__qPXRCRNQuZLLKto7CIIEzw* it_3;
		NI i_3;
		NI L_3;
		NI T12_;
		it_3 = (tyTuple__qPXRCRNQuZLLKto7CIIEzw*)0;
		i_3 = ((NI)0);
		T12_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.methodsPerType.len;
		L_3 = T12_;
		{
			while (1) {
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_3;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tmp_3;
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_3;
				tySequence__olFOFaYzOJN9aV5BWqK4b9bA T15_;
				tySequence__olFOFaYzOJN9aV5BWqK4b9bA* T16_;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T17_;
				if (!(i_3 < L_3)) goto LA14;
				it_3 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.methodsPerType.p->data[i_3]);
				key_3 = translateId__icZic_u21415((*it_3).Field0, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				tmp_3 = translateId__icZic_u21415((*it_3).Field1, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				symId_3.module = ((NI) (tmp_3.module));
				symId_3.packed_0 = (*it_3).Field1;
				T15_.len = 0; T15_.p = NIM_NIL;
				T15_.len = 0; T15_.p = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content*) newSeqPayload(0, sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA), NIM_ALIGNOF(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T16_ = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
				T16_ = mgetOrPut__icZreplayer_u1090((&(*g_p0).methodsPerType), key_3, T15_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimZeroMem((void*)(&T17_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T17_.id = symId_3;
				T17_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				add__modulegraphs_u6885((&(*T16_)), T17_);
				i_3 += ((NI)1);
			} LA14: ;
		}
	}
	{
		tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* it_4;
		NI i_4;
		NI L_4;
		NI T19_;
		it_4 = (tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig*)0;
		i_4 = ((NI)0);
		T19_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.dispatchers.len;
		L_4 = T19_;
		{
			while (1) {
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tmp_4;
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_4;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T22_;
				if (!(i_4 < L_4)) goto LA21;
				it_4 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.dispatchers.p->data[i_4]);
				tmp_4 = translateId__icZic_u21415((*it_4), (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				symId_4.module = ((NI) (tmp_4.module));
				symId_4.packed_0 = (*it_4);
				nimZeroMem((void*)(&T22_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T22_.id = symId_4;
				T22_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				add__modulegraphs_u6885((&(*g_p0).dispatchers), T22_);
				i_4 += ((NI)1);
			} LA21: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, replayGenericCacheInformation__icZreplayer_u1489)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1) {
NIM_BOOL oldNimErrFin34_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyTuple__qPXRCRNQuZLLKto7CIIEzw* it_1;
		tySequence__YYy1721YAuPF0ajBYHd8Wg* colontmp_;
		NI i_1;
		NI L_1;
		NI T2_;
		it_1 = (tyTuple__qPXRCRNQuZLLKto7CIIEzw*)0;
		colontmp_ = (tySequence__YYy1721YAuPF0ajBYHd8Wg*)0;
		colontmp_ = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.typeInstCache);
		i_1 = ((NI)0);
		T2_ = (*colontmp_).len;
		L_1 = T2_;
		{
			while (1) {
				tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig colontmpD_;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_1;
				tySequence__vb3AGHvMJTxdOSSwMmBmTQ T5_;
				tySequence__vb3AGHvMJTxdOSSwMmBmTQ* T6_;
				tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA T7_;
				if (!(i_1 < L_1)) goto LA4;
				it_1 = (&(*colontmp_).p->data[i_1]);
				key_1 = translateId__icZic_u21415((*it_1).Field0, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T5_.len = 0; T5_.p = NIM_NIL;
				T5_.len = 0; T5_.p = (tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content*) newSeqPayload(0, sizeof(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA), NIM_ALIGNOF(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
				T6_ = (tySequence__vb3AGHvMJTxdOSSwMmBmTQ*)0;
				T6_ = mgetOrPut__semdata_u6085((&(*g_p0).typeInstCache), key_1, T5_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimZeroMem((void*)(&T7_), sizeof(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
				T7_.id.module = module_p1;
				colontmpD_ = eqdup___icZpacked95ast_u675((*it_1).Field1);
				T7_.id.packed_0 = colontmpD_;
				T7_.typ = ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL);
				add__semdata_u7226((&(*T6_)), T7_);
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	{
		tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* it_2;
		NI i_2;
		NI L_2;
		NI T9_;
		it_2 = (tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg*)0;
		i_2 = ((NI)0);
		T9_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.procInstCache.len;
		L_2 = T9_;
		{
			while (1) {
				tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes_1;
				tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig colontmpD__2;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_2;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA sym_1;
				NI T13_;
				tySequence__apM9bRAO19cVjhWlxqd1PGeA T18_;
				tySequence__apM9bRAO19cVjhWlxqd1PGeA* T19_;
				tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA T20_;
				tySequence__YxH9cgSorHRI8ZPzHf47NNQ blitTmp_1;
				if (!(i_2 < L_2)) goto LA11;
				concreteTypes_1.len = 0; concreteTypes_1.p = NIM_NIL;
				it_2 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.procInstCache.p->data[i_2]);
				key_2 = translateId__icZic_u21415((*it_2).key, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				sym_1 = translateId__icZic_u21415((*it_2).sym, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				T13_ = (*it_2).concreteTypes.len;
				concreteTypes_1 = newSeq__icZreplayer_u1639((T13_));
				{
					NI i_3;
					NI colontmp__2;
					NI T15_;
					NI res_1;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					T15_ = ((*it_2).concreteTypes.len-1);
					colontmp__2 = T15_;
					res_1 = ((NI)0);
					{
						while (1) {
							tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig colontmpD__3;
							tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tmp_1;
							if (!(res_1 <= colontmp__2)) goto LA17;
							i_3 = ((NI) (res_1));
							tmp_1 = translateId__icZic_u21415((*it_2).concreteTypes.p->data[i_3], (*g_p0).packed_0, module_p1, (*g_p0).config);
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
							concreteTypes_1.p->data[i_3].module = ((NI) (tmp_1.module));
							colontmpD__3 = eqdup___icZpacked95ast_u675((*it_2).concreteTypes.p->data[i_3]);
							concreteTypes_1.p->data[i_3].packed_0 = colontmpD__3;
							res_1 += ((NI)1);
						} LA17: ;
					}
				}
				T18_.len = 0; T18_.p = NIM_NIL;
				T18_.len = 0; T18_.p = (tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content*) newSeqPayload(0, sizeof(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA), NIM_ALIGNOF(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
				T19_ = (tySequence__apM9bRAO19cVjhWlxqd1PGeA*)0;
				T19_ = mgetOrPut__semdata_u4860((&(*g_p0).procInstCache), key_2, T18_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				nimZeroMem((void*)(&T20_), sizeof(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
				T20_.module = module_p1;
				T20_.sym.module = ((NI) (sym_1.module));
				colontmpD__2 = eqdup___icZpacked95ast_u675((*it_2).sym);
				T20_.sym.packed_0 = colontmpD__2;
				blitTmp_1 = concreteTypes_1;
				eqwasMoved___modulegraphs_u1203((&concreteTypes_1));
				T20_.concreteTypes = blitTmp_1;
				T20_.inst = ((tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*) NIM_NIL);
				add__semdata_u6001((&(*T19_)), (&T20_));
				i_2 += ((NI)1);
				{
					LA12_:;
				}
				{
					eqdestroy___modulegraphs_u1206(concreteTypes_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA11: ;
		}
	}
	{
		tyTuple__TRK7rrwoha9bbDAdPWsqJMw* it_3;
		NI i_4;
		NI L_3;
		NI T24_;
		it_3 = (tyTuple__TRK7rrwoha9bbDAdPWsqJMw*)0;
		i_4 = ((NI)0);
		T24_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.methodsPerGenericType.len;
		L_3 = T24_;
		{
			while (1) {
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_3;
				NI col_1;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tmp_2;
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_1;
				tySequence__9bW2eTK9b7vXE70Sx5VPH1mw T27_;
				tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* T28_;
				tyTuple__lGHLhAAUpxgfrnQkIzNrMw T29_;
				if (!(i_4 < L_3)) goto LA26;
				it_3 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.methodsPerGenericType.p->data[i_4]);
				key_3 = translateId__icZic_u21415((*it_3).Field0, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				col_1 = (*it_3).Field1;
				tmp_2 = translateId__icZic_u21415((*it_3).Field2, (*g_p0).packed_0, module_p1, (*g_p0).config);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				symId_1.module = ((NI) (tmp_2.module));
				symId_1.packed_0 = (*it_3).Field2;
				T27_.len = 0; T27_.p = NIM_NIL;
				T27_.len = 0; T27_.p = (tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content*) newSeqPayload(0, sizeof(tyTuple__lGHLhAAUpxgfrnQkIzNrMw), NIM_ALIGNOF(tyTuple__lGHLhAAUpxgfrnQkIzNrMw));
				T28_ = (tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*)0;
				T28_ = mgetOrPut__modulegraphs_u9537((&(*g_p0).methodsPerGenericType), key_3, T27_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimZeroMem((void*)(&T29_), sizeof(tyTuple__lGHLhAAUpxgfrnQkIzNrMw));
				T29_.Field0 = col_1;
				T29_.Field1.id = symId_1;
				T29_.Field1.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				add__modulegraphs_u10641((&(*T28_)), (&T29_));
				i_4 += ((NI)1);
			} LA26: ;
		}
	}
	replayBackendProcs__icZreplayer_u893(g_p0, module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI32* it_4;
		NI i_5;
		NI L_4;
		NI T31_;
		it_4 = (NI32*)0;
		i_5 = ((NI)0);
		T31_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.methods.len;
		L_4 = T31_;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_2;
				tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T35_;
				tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T36_;
				tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig T37_;
				if (!(i_5 < L_4)) goto LA33;
				sym_2 = NIM_NIL;
				it_4 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.methods.p->data[i_5]);
				T35_ = NIM_NIL;
				T35_ = (*g_p0).config;
				T36_ = NIM_NIL;
				T36_ = (*g_p0).cache;
				T37_.module = ((NU32)0);
				T37_.item = (*it_4);
				sym_2 = loadSymFromId__icZic_u21336(T35_, T36_, (&(*g_p0).packed_0), module_p1, T37_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				methodDef__cgmeth_u202(g_p0, (*g_p0).idgen, sym_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				i_5 += ((NI)1);
				{
					LA34_:;
				}
				{
					oldNimErrFin34_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(sym_2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin34_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA33: ;
		}
	}
	{
		NI32* it_5;
		NI i_6;
		NI L_5;
		NI T41_;
		it_5 = (NI32*)0;
		i_6 = ((NI)0);
		T41_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.converters.len;
		L_5 = T41_;
		{
			while (1) {
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_2;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T44_;
				if (!(i_6 < L_5)) goto LA43;
				it_5 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.converters.p->data[i_6]);
				symId_2.module = module_p1;
				symId_2.packed_0.module = ((NU32)0);
				symId_2.packed_0.item = (*it_5);
				nimZeroMem((void*)(&T44_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T44_.id = symId_2;
				T44_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				add__modulegraphs_u6885((&(*g_p0).ifaces.p->data[module_p1].converters), T44_);
				i_6 += ((NI)1);
			} LA43: ;
		}
	}
	{
		NI32* it_6;
		NI i_7;
		NI L_6;
		NI T46_;
		it_6 = (NI32*)0;
		i_7 = ((NI)0);
		T46_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.trmacros.len;
		L_6 = T46_;
		{
			while (1) {
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_3;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T49_;
				if (!(i_7 < L_6)) goto LA48;
				it_6 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.trmacros.p->data[i_7]);
				symId_3.module = module_p1;
				symId_3.packed_0.module = ((NU32)0);
				symId_3.packed_0.item = (*it_6);
				nimZeroMem((void*)(&T49_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T49_.id = symId_3;
				T49_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				add__modulegraphs_u6885((&(*g_p0).ifaces.p->data[module_p1].patterns), T49_);
				i_7 += ((NI)1);
			} LA48: ;
		}
	}
	{
		NI32* it_7;
		NI i_8;
		NI L_7;
		NI T51_;
		it_7 = (NI32*)0;
		i_8 = ((NI)0);
		T51_ = (*g_p0).packed_0.pm.p->data[module_p1].fromDisk.pureEnums.len;
		L_7 = T51_;
		{
			while (1) {
				tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ symId_4;
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T54_;
				if (!(i_8 < L_7)) goto LA53;
				it_7 = (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk.pureEnums.p->data[i_8]);
				symId_4.module = module_p1;
				symId_4.packed_0.module = ((NU32)0);
				symId_4.packed_0.item = (*it_7);
				nimZeroMem((void*)(&T54_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
				T54_.id = symId_4;
				T54_.sym = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				add__modulegraphs_u6885((&(*g_p0).ifaces.p->data[module_p1].pureEnums), T54_);
				i_8 += ((NI)1);
			} LA53: ;
		}
	}
	}BeforeRet_: ;
}
